//+------------------------------------------------------------------+
//|                                                  Daily Pivot.mq4 |
//|                                                         value808 |
//|                                                            v.0.1 |
//+------------------------------------------------------------------+
#property copyright "value808"
#property link      ""

#property indicator_chart_window
#property indicator_buffers 3

#property indicator_color1 Crimson
#property indicator_color2 Crimson
#property indicator_color3 Crimson

double ExtMapBuffer0[];
double ExtMapBuffer1[];
double ExtMapBuffer2[];

//---- input parameters
extern int       Offset.Hours = 0;
extern int       Offset.Minutes = 0;
extern int       Pivot.1.Calculation.Method = PRICE_TYPICAL; // Corresponds to the "Applied price constants" mapping (see manual for details).
extern int       Pivot.2.Calculation.Method = PRICE_HIGH; // Corresponds to the "Applied price constants" mapping (see manual for details).
extern int       Pivot.3.Calculation.Method = PRICE_LOW; // Corresponds to the "Applied price constants" mapping (see manual for details).
extern bool      Show.Pivot.2 = false;
extern bool      Show.Pivot.3 = false;
extern bool      Use.Lines = false;
extern int       Arrow.Code = 158;
extern int       Bars.To.Count = 500;

bool active = true;
double pivotPrice = 0, pivot2Price = 0, pivot3Price = 0;

int chartPeriod, chartPeriodHours, chartPeriodMinutes;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
  
   chartPeriod = Period();
   chartPeriodHours = chartPeriod/PERIOD_H1;
	chartPeriodMinutes = chartPeriod/PERIOD_M1;
	  
   if (chartPeriod>PERIOD_D1) {
      Alert("Not suitable for periods higher than D1!");
      active = false;
   }
   
   int indicatorType = 0;
   if (Use.Lines) indicatorType = DRAW_LINE; else indicatorType = DRAW_ARROW;
   
   SetIndexStyle(0,indicatorType,EMPTY,1);
   SetIndexArrow(0,Arrow.Code);
   SetIndexBuffer(0,ExtMapBuffer0);
   SetIndexStyle(1,indicatorType,EMPTY,1);
   SetIndexArrow(1,Arrow.Code);
   SetIndexBuffer(1,ExtMapBuffer1);
   SetIndexStyle(2,indicatorType,EMPTY,1);
   SetIndexArrow(2,Arrow.Code);
   SetIndexBuffer(2,ExtMapBuffer2);

   return(0);
  }
  

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//----
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   if (!active) return (1);
	int counted_bars = IndicatorCounted();
	if (counted_bars<0)  { return (-1); }

   int limit = Bars - counted_bars - 1;	

   if (Bars.To.Count != 0 && limit > Bars.To.Count) limit = Bars.To.Count;
	
	int lastDay = 0;
	
	for (int i=limit; i>=0; i--) {
	  
	  datetime timeBar = iTime(NULL,0,i);
	  
	  int curDay = TimeDayOfWeek(timeBar);
	  int curHour = TimeHour(timeBar);
	  int curMinute = TimeMinute(timeBar);
	  
	  if (lastDay != curDay && ((curHour + chartPeriodHours >= Offset.Hours && curMinute + chartPeriodMinutes > Offset.Minutes) ||
	        (curHour > Offset.Hours))) {
	  
	  	  lastDay = curDay;
   	  
   	  datetime pivotChangeTime = timeBar;

 	     if (curHour != Offset.Hours) {
 	       pivotChangeTime -= curHour*3600;
  	       pivotChangeTime += Offset.Hours*3600;
  	     }

        if (curMinute != Offset.Minutes) {
      	  pivotChangeTime -= curMinute*60;
      	  pivotChangeTime += Offset.Minutes*60;
        }

    	  datetime openTime = 0;
    	  if (curDay == 1) {
    	    openTime = pivotChangeTime-3*PERIOD_D1*60; 
    	  } else {
    	    openTime = pivotChangeTime-PERIOD_D1*60;
    	  }
 	     
	     int barShiftOpen = iBarShift(NULL,PERIOD_M1,openTime,false);
	     int barShiftClose = iBarShift(NULL,PERIOD_M1,pivotChangeTime-PERIOD_M1*60,false);
 	     int periods = barShiftOpen - barShiftClose;

	     double openPrice = iOpen(NULL,PERIOD_M1,barShiftOpen);
	     double closePrice = iClose(NULL,PERIOD_M1,barShiftClose);
	     double highPrice = iHigh(NULL,PERIOD_M1,Highest(NULL,PERIOD_M1,MODE_HIGH,periods,barShiftClose));
	     double lowPrice = iLow(NULL,PERIOD_M1,Lowest(NULL,PERIOD_M1,MODE_LOW,periods,barShiftClose));

        switch (Pivot.1.Calculation.Method) {
            case PRICE_CLOSE:    pivotPrice = closePrice; break;
            case PRICE_OPEN:     pivotPrice = openPrice; break;
            case PRICE_HIGH:     pivotPrice = highPrice; break;
            case PRICE_LOW:      pivotPrice = lowPrice; break;
            case PRICE_MEDIAN:   pivotPrice = (highPrice+lowPrice)/2; break;
            case PRICE_TYPICAL:  pivotPrice = (highPrice+lowPrice+closePrice)/3; break;
            case PRICE_WEIGHTED: pivotPrice = (highPrice+lowPrice+2*closePrice)/4; break;
        }

        switch (Pivot.2.Calculation.Method) {
            case PRICE_CLOSE:    pivot2Price = closePrice; break;
            case PRICE_OPEN:     pivot2Price = openPrice; break;
            case PRICE_HIGH:     pivot2Price = highPrice; break;
            case PRICE_LOW:      pivot2Price = lowPrice; break;
            case PRICE_MEDIAN:   pivot2Price = (highPrice+lowPrice)/2; break;
            case PRICE_TYPICAL:  pivot2Price = (highPrice+lowPrice+closePrice)/3; break;
            case PRICE_WEIGHTED: pivot2Price = (highPrice+lowPrice+2*closePrice)/4; break;
        }

        switch (Pivot.3.Calculation.Method) {
            case PRICE_CLOSE:    pivot3Price = closePrice; break;
            case PRICE_OPEN:     pivot3Price = openPrice; break;
            case PRICE_HIGH:     pivot3Price = highPrice; break;
            case PRICE_LOW:      pivot3Price = lowPrice; break;
            case PRICE_MEDIAN:   pivot3Price = (highPrice+lowPrice)/2; break;
            case PRICE_TYPICAL:  pivot3Price = (highPrice+lowPrice+closePrice)/3; break;
            case PRICE_WEIGHTED: pivot3Price = (highPrice+lowPrice+2*closePrice)/4; break;
        }
	     
	  }
      
	  ExtMapBuffer0[i]=pivotPrice;
	  
	  if (Show.Pivot.2) ExtMapBuffer1[i]=pivot2Price;
	  if (Show.Pivot.3) ExtMapBuffer2[i]=pivot3Price;


	}

   return(0);
  }
//+------------------------------------------------------------------+